/*------------------------------------------------------------------------------------
   Name: xSuperTrend MTF.mq4
   Copyright 2011, Xaphod, http://wwww.xaphod.com
   
   Description: MTF SuperTrend Indicator
                Requires that xSuperTrend.mq4 is installed to work.
	          
   Change log: 
       2011-12-04. Xaphod, v1.00 
          - First Release 
-------------------------------------------------------------------------------------*/
// Indicator properties
#property copyright "Copyright  2011, Xaphod"
#property link      "http://wwww.xaphod.com"

#property indicator_chart_window
#property indicator_buffers 3
#property indicator_color1 Yellow
#property indicator_color2 FireBrick
#property indicator_color3 Green
#property indicator_width1 1
#property indicator_width2 2
#property indicator_width3 2
#property indicator_style1 STYLE_DOT
#property indicator_maximum 1
#property indicator_minimum 0

// Constant definitions
#define INDICATOR_NAME "xSuperTrend MTF"
#define INDICATOR_VERSION "v1.00, www.xaphod.com"

// Indicator parameters
extern string Version_Info=INDICATOR_VERSION;
extern string SuperTrend_Info="";
extern int    SuperTrend_Period=10;      // SuperTrend ATR Period
extern double SuperTrend_Multiplier=1.7; // SuperTrend Multiplier
extern bool   SuperTrend_AutoTF=True;    // Select next higher TF_ If TF=M15 then H1 is selected
extern int    SuperTrend_TimeFrame=0;    // SuperTrend Timeframe

// Global module varables
double gadUpBuf[];
double gadDnBuf[];
double gadSuperTrend[];
int giTimeFrame;
int giRepaintBars;

//-----------------------------------------------------------------------------
// function: init()
// Description: Custom indicator initialization function_
//-----------------------------------------------------------------------------
int init() {
   SetIndexStyle(0, DRAW_LINE);
   SetIndexBuffer(0, gadSuperTrend);
   SetIndexLabel(0, "SuperTrend");
   SetIndexStyle(1, DRAW_LINE);
   SetIndexBuffer(1, gadDnBuf);
   SetIndexLabel(1, "SuperTrend Down");
   SetIndexStyle(2, DRAW_LINE);
   SetIndexBuffer(2, gadUpBuf);
   SetIndexLabel(2, "SuperTrend Up");
   // Set Timeframe
  if (SuperTrend_AutoTF)
    giTimeFrame=NextHigherTF(SuperTrend_TimeFrame);
  else
    giTimeFrame=SuperTrend_TimeFrame;
   //Init vars
  giRepaintBars=SuperTrend_TimeFrame/Period()+2;
  IndicatorShortName(INDICATOR_NAME+" "+TF2Str(giTimeFrame) +"["+SuperTrend_Period+";"+DoubleToStr(SuperTrend_Multiplier,1)+"]");

  return(0);
}


//-----------------------------------------------------------------------------
// function: deinit()
// Description: Custom indicator deinitialization function_
//-----------------------------------------------------------------------------
int deinit() {
   return (0);
}


///-----------------------------------------------------------------------------
// function: start()
// Description: Custom indicator iteration function.
//-----------------------------------------------------------------------------
int start() {
  int iNewBars, iCountedBars, i;
  
  // Get unprocessed ticks
  iCountedBars=IndicatorCounted();
  if(iCountedBars < 0) return (-1); 
  if(iCountedBars>0) iCountedBars--;
  iNewBars=Bars-iCountedBars;
  iNewBars=MathMax(giRepaintBars,iNewBars);
  
  for(i=iNewBars; i>=0; i--) {
    // Get SuperTrend data
    gadUpBuf[i]=EMPTY_VALUE;
    gadDnBuf[i]=EMPTY_VALUE;
    gadSuperTrend[i]=iCustom(NULL,giTimeFrame,"xSuperTrend","","",SuperTrend_Period,SuperTrend_Multiplier,0,iBarShift(Symbol(), giTimeFrame, Time[i]));
    gadDnBuf[i]=iCustom(NULL,giTimeFrame,"xSuperTrend","","",SuperTrend_Period,SuperTrend_Multiplier,1,iBarShift(Symbol(), giTimeFrame, Time[i]));
    gadUpBuf[i]=iCustom(NULL,giTimeFrame,"xSuperTrend","","",SuperTrend_Period,SuperTrend_Multiplier,2,iBarShift(Symbol(), giTimeFrame, Time[i]));
  }
  
  return(0);
}
//+------------------------------------------------------------------+


//-----------------------------------------------------------------------------
// function: TF2Str()
// Description: Convert time-frame to a string
//-----------------------------------------------------------------------------
string TF2Str(int iPeriod) {
  switch(iPeriod) {
    case PERIOD_M1: return("M1");
    case PERIOD_M5: return("M5");
    case PERIOD_M15: return("M15");
    case PERIOD_M30: return("M30");
    case PERIOD_H1: return("H1");
    case PERIOD_H4: return("H4");
    case PERIOD_D1: return("D1");
    case PERIOD_W1: return("W1");
    case PERIOD_MN1: return("MN1");
    default: return("M"+iPeriod);
  }
}


//-----------------------------------------------------------------------------
// function: NextHigherTF()
// Description: Select the next higher time-frame. 
//              Note: M15 and M30 both select H1 as next higher TF. 
//-----------------------------------------------------------------------------
int NextHigherTF(int iPeriod) {
  if (iPeriod==0) iPeriod=Period();
  switch(iPeriod) {
    case PERIOD_M1: return(PERIOD_M5);
    case PERIOD_M5: return(PERIOD_M15);
    case PERIOD_M15: return(PERIOD_H1);
    case PERIOD_M30: return(PERIOD_H1);
    case PERIOD_H1: return(PERIOD_H4);
    case PERIOD_H4: return(PERIOD_D1);
    case PERIOD_D1: return(PERIOD_W1);
    case PERIOD_W1: return(PERIOD_MN1);
    case PERIOD_MN1: return(PERIOD_MN1);
    default: return(Period());
  }
}